@@ -14,4 +14,4 @@ class validator(object):
 		func.validator = True
 		func.key = self.key
 		func.error = self.error
-		return classmethod(func)
\ No newline at end of file
+		return func
\ No newline at end of file
